@@ -22,13 +22,11 @@
 #ifndef HELP_H
 #define HELP_H
 
+#include "gui/linkhandler.h"
+#include "gui/widgets/window.h"
+
 #include <guichan/actionlistener.hpp>
 
-#include "window.h"
-#include "linkhandler.h"
-
-#include "../guichanfwd.h"
-
 class BrowserBox;
 
 /**
@@ -51,7 +49,7 @@ class HelpWindow : public Window, public LinkHandler,
         /**
          * Handles link action.
          */
-        void handleLink(const std::string& link);
+        void handleLink(const std::string &link);
 
         /**
          * Loads help in the dialog.
@@ -61,7 +59,7 @@ class HelpWindow : public Window, public LinkHandler,
     private:
         void loadFile(const std::string &file);
 
-        BrowserBox* mBrowserBox;
+        BrowserBox *mBrowserBox;
         gcn::ScrollArea *mScrollArea;
 };
 
