@@ -203,13 +203,13 @@ Setup_Video::Setup_Video():
     mFpsCheckBox(new CheckBox(_("FPS Limit:"))),
     mFpsSlider(new Slider(10, 120)),
     mFpsField(new TextField),
-    mOverlayDetail((int) config.getValue("OverlayDetail", 2)),
+    mOverlayDetail((int) config.getValue("OverlayDetail", 1)),
     mOverlayDetailSlider(new Slider(0, 2)),
     mOverlayDetailField(new Label("")),
     mParticleDetail(3 - (int) config.getValue("particleEmitterSkip", 1)),
     mParticleDetailSlider(new Slider(0, 3)),
     mParticleDetailField(new Label("")),
-    mFontSize((int) config.getValue("fontSize", 11))
+    mFontSize((int) config.getValue("fontSize", 13))
 {
     setName(_("Video"));
 
@@ -342,7 +342,7 @@ void Setup_Video::apply()
          * See http://libsdl.org/cgi/docwiki.cgi/SDL_SetVideoMode
          */
 
-#if defined(WIN32) || defined(__APPLE__)
+#if defined(WIN32) || defined(__APPLE__) || defined(MAEMO)
         // checks for opengl usage
         if (!(config.getValue("opengl", false) == 1))
         {
@@ -360,7 +360,7 @@ void Setup_Video::apply()
                     logger->error(error.str());
                 }
             }
-#if defined(WIN32) || defined(__APPLE__)
+#if defined(WIN32) || defined(__APPLE__) || defined(MAEMO)
         }
         else
         {
@@ -395,7 +395,7 @@ void Setup_Video::apply()
     mSpeechMode = static_cast<Being::Speech>(
             config.getValue("speech", Being::TEXT_OVERHEAD));
     mOpacity = config.getValue("guialpha", 0.8);
-    mOverlayDetail = (int) config.getValue("OverlayDetail", 2);
+    mOverlayDetail = (int) config.getValue("OverlayDetail", 1);
     mOpenGLEnabled = config.getValue("opengl", false);
     mPickupChatEnabled = config.getValue("showpickupchat", true);
     mPickupParticleEnabled = config.getValue("showpickupparticle", false);
