@@ -92,7 +92,7 @@ static KeyData const keyData[KeyboardConfig::KEY_TOTAL] = {
     {"keyEmoteShortcut10", SDLK_0, strprintf(_("Emote Shortcut %d"), 10)},
     {"keyEmoteShortcut11", SDLK_MINUS, strprintf(_("Emote Shortcut %d"), 11)},
     {"keyEmoteShortcut12", SDLK_EQUALS, strprintf(_("Emote Shortcut %d"), 12)},
-    {"keyChat", SDLK_RETURN, _("Toggle Chat")},
+    {"keyChat", SDLK_KP_ENTER, _("Toggle Chat")},
     {"keyChatScrollUp", SDLK_PAGEUP, _("Scroll Chat Up")},
     {"keyChatScrollDown", SDLK_PAGEDOWN, _("Scroll Chat Down")},
     {"keyChatPrevTab", SDLK_LEFTBRACKET, _("Previous Chat Tab")},
