@@ -144,7 +144,7 @@ namespace
 }
 
 static const int defaultScreenWidth = 800;
-static const int defaultScreenHeight = 600;
+static const int defaultScreenHeight = 480;
 
 static const int defaultSfxVolume = 100;
 static const int defaultMusicVolume = 60;
@@ -360,9 +360,9 @@ static void initConfiguration(const Options &options)
 #else
     config.setValue("opengl", false);
 #endif
-    config.setValue("screen", false);
+    config.setValue("screen", true);
     config.setValue("sound", true);
-    config.setValue("guialpha", 0.8f);
+    config.setValue("guialpha", 1.0f);
     config.setValue("remember", true);
     config.setValue("sfxVolume", 100);
     config.setValue("musicVolume", 60);
