@@ -19,34 +19,31 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "monster.h"
-
 #include "animatedsprite.h"
 #include "game.h"
-#include "sound.h"
-#include "particle.h"
-#include "text.h"
 #include "localplayer.h"
+#include "monster.h"
+#include "particle.h"
+#include "sound.h"
+#include "text.h"
+
+#include "gui/palette.h"
 
 #include "resources/monsterdb.h"
+#include "resources/monsterinfo.h"
 
-#include "utils/tostring.h"
-
-static const int NAME_X_OFFSET = 16;
-static const int NAME_Y_OFFSET = 16;
-
-Monster::Monster(Uint32 id, Uint16 job, Map *map):
+Monster::Monster(int id, int job, Map *map):
     Being(id, job, map),
     mText(0)
 {
-    const MonsterInfo&  info = MonsterDB::get(job - 1002);
+    const MonsterInfo& info = getInfo();
 
     // Setup Monster sprites
     int c = BASE_SPRITE;
     const std::list<std::string> &sprites = info.getSprites();
+
     for (std::list<std::string>::const_iterator i = sprites.begin();
-         i != sprites.end();
-         i++)
+         i != sprites.end(); i++)
     {
         if (c == VECTOREND_SPRITE) break;
 
@@ -61,47 +58,51 @@ Monster::Monster(Uint32 id, Uint16 job, Map *map):
         mSprites[c] = AnimatedSprite::load("graphics/sprites/error.xml");
     }
 
-    const std::list<std::string> &particleEffects = info.getParticleEffects();
-    for (   std::list<std::string>::const_iterator i = particleEffects.begin();
-            i != particleEffects.end();
-            i++
-        )
+    if (mParticleEffects)
     {
-        controlParticle(particleEngine->addEffect((*i), 0, 0));
+        const std::list<std::string> &particleEffects = info.getParticleEffects();
+        for (std::list<std::string>::const_iterator i = particleEffects.begin();
+             i != particleEffects.end(); i++)
+        {
+            controlParticle(particleEngine->addEffect((*i), 0, 0));
+        }
     }
+
+    mNameColor = &guiPalette->getColor(Palette::MONSTER);
+
+    Being::setName(getInfo().getName());
 }
 
 Monster::~Monster()
 {
-    if (mText)
-    {
-        player_node->setTarget(0);
-    }
+    delete mText;
 }
 
+#ifdef EATHENA_SUPPORT
 void Monster::logic()
 {
     if (mAction != STAND)
     {
-        mFrame = (get_elapsed_time(mWalkTime) * 4) / mWalkSpeed;
+        mFrame = (get_elapsed_time(mWalkTime) * 4) / getWalkSpeed();
 
         if (mFrame >= 4 && mAction != DEAD)
-        {
             nextStep();
-        }
     }
 
     Being::logic();
 }
+#endif
 
 Being::Type Monster::getType() const
 {
     return MONSTER;
 }
 
-void Monster::setAction(Uint8 action)
+void Monster::setAction(Action action, int attackType)
 {
     SpriteAction currentAction = ACTION_INVALID;
+    int rotation = 0;
+    std::string particleEffect;
 
     switch (action)
     {
@@ -113,15 +114,35 @@ void Monster::setAction(Uint8 action)
             sound.playSfx(getInfo().getSound(MONSTER_EVENT_DIE));
             break;
         case ATTACK:
-            currentAction = ACTION_ATTACK;
+            currentAction = getInfo().getAttackAction(attackType);
             mSprites[BASE_SPRITE]->reset();
+
+            //attack particle effect
+            particleEffect = getInfo().getAttackParticleEffect(attackType);
+            if (!particleEffect.empty() && mParticleEffects)
+            {
+                switch (mDirection)
+                {
+                    case DOWN: rotation = 0; break;
+                    case LEFT: rotation = 90; break;
+                    case UP: rotation = 180; break;
+                    case RIGHT: rotation = 270; break;
+                    default: break;
+                }
+                Particle *p;
+                p = particleEngine->addEffect(particleEffect, 0, 0, rotation);
+                controlParticle(p);
+            }
             break;
         case STAND:
-            currentAction = ACTION_STAND;
-            break;
+           currentAction = ACTION_STAND;
+           break;
         case HURT:
-            // Not implemented yet
-            break;
+           // Not implemented yet
+           break;
+        case SIT:
+           // Also not implemented yet
+           break;
     }
 
     if (currentAction != ACTION_INVALID)
@@ -129,27 +150,45 @@ void Monster::setAction(Uint8 action)
         for (int i = 0; i < VECTOREND_SPRITE; i++)
         {
             if (mSprites[i])
-            {
                 mSprites[i]->play(currentAction);
-            }
         }
         mAction = action;
     }
 }
 
-void Monster::handleAttack(Being *victim, int damage)
+#ifdef TMWSERV_SUPPORT
+
+void Monster::handleAttack()
 {
-    Being::handleAttack(victim, damage);
+    Being::handleAttack();
+
+    const MonsterInfo &mi = getInfo();
+
+    // TODO: It's not possible to determine hit or miss here, so this stuff
+    // probably needs to be moved somewhere else. We may lose synchronization
+    // between attack animation and the sound, unless we adapt the protocol...
+    sound.playSfx(mi.getSound(MONSTER_EVENT_HIT));
+}
+
+#else
+
+void Monster::handleAttack(Being *victim, int damage, AttackType type)
+{
+    Being::handleAttack(victim, damage, type);
 
     const MonsterInfo &mi = getInfo();
     sound.playSfx(mi.getSound((damage > 0) ?
                 MONSTER_EVENT_HIT : MONSTER_EVENT_MISS));
 }
 
-void Monster::takeDamage(int amount)
+#endif
+
+void Monster::takeDamage(Being *attacker, int amount, AttackType type)
 {
-    if (amount > 0) sound.playSfx(getInfo().getSound(MONSTER_EVENT_HURT));
-    Being::takeDamage(amount);
+    if (amount > 0)
+        sound.playSfx(getInfo().getSound(MONSTER_EVENT_HURT));
+
+    Being::takeDamage(attacker, amount, type);
 }
 
 Being::TargetCursorSize Monster::getTargetCursorSize() const
@@ -159,18 +198,20 @@ Being::TargetCursorSize Monster::getTargetCursorSize() const
 
 const MonsterInfo &Monster::getInfo() const
 {
-    return MonsterDB::get(mJob - 1002);
+    return MonsterDB::get(mJob);
 }
 
-void Monster::showName(bool show)
+void Monster::setShowName(bool show)
 {
     delete mText;
+
     if (show)
     {
-        mText = new Text(getInfo().getName(), mPx + NAME_X_OFFSET,
-                         mPy + NAME_Y_OFFSET - getHeight(),
+        mText = new Text(getInfo().getName(),
+                         getPixelX(),
+                         getPixelY() - getHeight(),
                          gcn::Graphics::CENTER,
-                         gcn::Color(255, 64, 64));
+                         &guiPalette->getColor(Palette::MONSTER));
     }
     else
     {
@@ -182,7 +223,7 @@ void Monster::updateCoords()
 {
     if (mText)
     {
-        mText->adviseXY(mPx + NAME_X_OFFSET,
-                        mPy + NAME_Y_OFFSET - getHeight());
+        mText->adviseXY(getPixelX(),
+                        getPixelY() - getHeight() - mText->getHeight());
     }
 }
