@@ -22,12 +22,12 @@
 #ifndef SIMPLEANIMAION_H
 #define SIMPLEANIMAION_H
 
-#include "resources/animation.h"
-
 #include "utils/xml.h"
 
+class Animation;
 class Frame;
 class Graphics;
+class Image;
 
 /**
  * This class is a leightweight alternative to the AnimatedSprite class.
@@ -39,12 +39,7 @@ class SimpleAnimation
         /**
          * Creates a simple animation with an already created animation.
          */
-        SimpleAnimation(Animation *animation):
-            mAnimation(animation),
-            mAnimationTime(0),
-            mAnimationPhase(0),
-            mCurrentFrame(mAnimation->getFrame(0))
-        {};
+        SimpleAnimation(Animation *animation);
 
         /**
          * Creates a simple animation that creates its animation from XML Data.
@@ -53,7 +48,18 @@ class SimpleAnimation
 
         ~SimpleAnimation();
 
-        void update(unsigned int timePassed);
+        void setFrame(int frame);
+
+        int getLength() const;
+
+        void update(int timePassed);
+
+        bool draw(Graphics* graphics, int posX, int posY) const;
+
+        /**
+         * Resets the animation.
+         */
+        void reset();
 
         Image *getCurrentImage() const;
 
@@ -62,10 +68,10 @@ class SimpleAnimation
         Animation *mAnimation;
 
         /** Time in game ticks the current frame is shown. */
-        unsigned int mAnimationTime;
+        int mAnimationTime;
 
         /** Index of current animation phase. */
-        unsigned int mAnimationPhase;
+        int mAnimationPhase;
 
         /** Current animation phase. */
         Frame *mCurrentFrame;
